@@ -1,6 +1,10 @@
+from django.utils.translation import ugettext_lazy as _
+
 from cms.plugin_base import CMSPluginBase
 from cms.plugin_pool import plugin_pool
-from django.utils.translation import ugettext_lazy as _
+from cms.utils import get_language_from_request
+
+from simple_translation.utils import get_translation_filter_language
 
 from cmsplugin_blog.models import LatestEntriesPlugin, Entry
 
@@ -19,9 +23,9 @@ class CMSLatestEntriesPlugin(CMSPluginBase):
         qs = Entry.published.all()
         
         if instance.current_language_only:
-            from cms.utils import get_language_from_request
             language = get_language_from_request(context["request"])
-            qs = qs.filter(entrytitle__language=language)
+            kw = get_translation_filter_language(Entry, language)
+            qs = qs.filter(**kw)
             
         latest = qs[:instance.limit]
         context.update({
