@@ -1,5 +1,6 @@
 from django.conf.urls.defaults import *
 from django.contrib import admin
+from cmsplugin_blog.sitemaps import BlogSitemap
 
 admin.autodiscover()
 
@@ -8,6 +9,12 @@ urlpatterns = patterns('',
     (r'^jsi18n/(?P<packages>\S+?)/$', 'django.views.i18n.javascript_catalog'),
 )
 
+
 urlpatterns += patterns('',
-    url(r'^', include('cms.urls')),
+    url(r'^sitemap\.xml$', 'django.contrib.sitemaps.views.sitemap', {
+        'sitemaps': {
+            'blogentries': BlogSitemap
+        }
+    }),
+    url(r'^', include('cms.urls'))
 )
